;;
;; Readline test
;;
;; By YOKOTA Hiroshi

(use gauche.test)
(use readline)
(test-section "readline")

(test-module 'readline)

(define histfile "./test-history")

(define (root-user?)
  (= (sys-getuid) 0))

(sys-unlink histfile)

(test "rl-read-history! :file not found" 'unused
      (lambda ()
	(rl-read-history! histfile))
      (lambda (expect result) (not (= result 0))))

(test "rl-write-history :write success" 0
      (lambda ()
	(rl-add-history! "1")
	(rl-add-history! "2")
	(rl-add-history! "3")
	(rl-write-history histfile)
	))

(test "rl-read-history! :read success" 0
      (lambda ()
	(rl-read-history! histfile)))

(sys-chmod histfile #o000)

(if (root-user?)
    (begin
      (test "rl-write-history :can't write (skip)" #f (lambda () #f))
      (test "rl-read-history! :can't read (skip)"  #f (lambda () #f))
      )

    (begin
      (test "rl-write-history :can't write" 'unused
	    (lambda ()
	      (rl-write-history histfile))
	    (lambda (expect result) (not (= result 0))))

      (test "rl-read-history! :can't read" 'unused
	    (lambda ()
	      (rl-read-history! histfile))
	    (lambda (expect result) (not (= result 0))))
      ))

(sys-chmod histfile #o600)

(test* "rl-set-name!   " *test-error* (rl-set-name!))
(test* "rl-set-name! #t" *test-error* (rl-set-name! #t))
(test* "rl-set-name!  1" *test-error* (rl-set-name! 1))
(test* "rl-set-name! 'a" *test-error* (rl-set-name! 'a))

(test* "rl-set-completion-list-function!   " *test-error*
       (rl-set-completion-list-function!))
(test* "rl-set-completion-list-function! #t" *test-error*
       (rl-set-completion-list-function! #t))
(test* "rl-set-completion-list-function!  1" *test-error*
       (rl-set-completion-list-function! 1))
(test* "rl-set-completion-list-function! 'a" *test-error*
       (rl-set-completion-list-function! 'a))

(test* "rl-rl-set-prompt! :ps1 1" *test-error* (rl-rl-set-prompt! :ps1 1))
(test* "rl-set-prompt-state!  1" *test-error* (rl-set-prompt-state! 1))
(test* "rl-set-prompt-state! 'a" *test-error* (rl-set-prompt-state! 'a))

(sys-unlink histfile)

(test-end)

;; end
